@@ -4,7 +4,7 @@ use Moose;
 use Scalar::Util 'blessed';
 with 'Dist::Zilla::Role::PluginBundle::Easy', 'Dist::Zilla::Role::PluginBundle::Config::Slicer';
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 sub configure {
 	my $self = shift;
@@ -43,7 +43,12 @@ sub configure {
 	# @Basic, with some modifications
 	$self->add_plugins(qw/PruneCruft ManifestSkip MetaYAML MetaJSON
 		License ReadmeAnyFromPod ExtraTests ExecDir ShareDir/);
-	if (defined $self->payload->{makemaker} and lc $self->payload->{makemaker} eq 'awesome') {
+	
+	my %accepted_installers = map { ($_ => 1) } qw(MakeMaker MakeMaker::Awesome ModuleBuildTiny);
+	if (defined (my $installer = $self->payload->{installer})) {
+		die "Invalid installer $installer\n" unless exists $accepted_installers{$installer};
+		$self->add_plugins($installer);
+	} elsif (defined $self->payload->{makemaker} and lc $self->payload->{makemaker} eq 'awesome') {
 		$self->add_plugins('MakeMaker::Awesome');
 	} else {
 		$self->add_plugins('MakeMaker');
@@ -62,7 +67,7 @@ built by DBOOK
 =head1 SYNOPSIS
 
  [@Author::DBOOK]
- makemaker = awesome
+ installer = MakeMaker::Awesome
  MakeMaker::Awesome.test_file[] = t/*.t
  Git::GatherDir.exclude_filename[0] = bad_file
  Git::GatherDir.exclude_filename[1] = another_file
@@ -166,6 +171,16 @@ Additionally, the following options are provided.
 Set the user whose repository should be linked in metadata. Defaults to
 C<Grinnz>, change this when the main repository is elsewhere.
 
+=head2 installer
+
+ installer = ModuleBuildTiny
+ ModuleBuildTiny.version_method = installed
+
+Set the L<Dist::Zilla> installer plugin to use. Allowed installers are
+C<MakeMaker>, C<MakeMaker::Awesome>, and C<ModuleBuildTiny>. Options for the
+selected installer can be specified using config slicing. Overrides
+L</"makemaker"> option.
+
 =head2 makemaker
 
  makemaker = awesome
